@@ -1,10 +1,11 @@
 import subprocess
 import sys
 
-
 def run(args):
-    scr, packages, modules, extrapath, exitwithstatus = args
+    scr, defaults, packages, modules, extrapath, exitwithstatus = args
+
     cmdargs = [scr, 'test']
+    cmdargs.extend(defaults)
     cmdargs.extend(['-s'+x for x in packages])
     cmdargs.extend(['-m'+x for x in modules])
     cmdargs.extend(['--path '+x for x in extrapath])
